slepc-3.18.0 2022-10-01
Report Typos and Errors

# SVDErrorType

The error type used to assess accuracy of computed solutions

### Synopsis

    typedef enum { SVD_ERROR_ABSOLUTE,
                   SVD_ERROR_RELATIVE,
                   SVD_ERROR_NORM } SVDErrorType;

### See Also

SVDComputeError()

### Level

intermediate

### Location

include/slepcsvd.h

### Examples

src/svd/tutorials/ex14.c.html
src/svd/tutorials/ex15.c.html
src/svd/tutorials/ex15f.F.html
src/svd/tutorials/ex45.c.html
src/svd/tutorials/ex48.c.html
src/svd/tutorials/ex51.c.html
src/svd/tutorials/ex52.c.html
Index of all SVD routines
Table of Contents for all manual pages
Index of all manual pages